@@ -22,9 +22,9 @@ import re
 import eventlet
 from eventlet import tpool
 from neutron.agent import rpc as agent_rpc
-from neutron.common import rpc as n_rpc
 from neutron_lib.agent import topics
 from neutron_lib import constants as n_const
+from neutron_lib import rpc as n_rpc
 from os_win import constants as os_win_const
 from os_win import exceptions as os_win_exc
 from oslo_concurrency import lockutils
@@ -353,7 +353,7 @@ class Layer2Agent(base_agent.BaseAgent):
         """Process the new devices."""
         try:
             devices_details_list = self._plugin_rpc.get_devices_details_list(
-                self._context, self._added_ports, self._agent_id, self._host)
+                self._context, self._added_ports, self._agent_id)
         except Exception as exc:
             LOG.debug("Unable to get ports details for "
                       "devices %(devices)s: %(exc)s",
